<?php

namespace MS\Patchtest\Controller;

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2014 Manuel Selbach <manuel_selbach@yahoo.de>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use \TYPO3\CMS\Core\Messaging\AbstractMessage;

class FirstRegistrationController extends AbstractController
{
    /**
     * userRepository
     *
     * @var \MS\Patchtest\Domain\Repository\UserRepository
     * @inject
     */
    protected $userRepository;

    /**
     * @var \TYPO3\CMS\Extbase\Persistence\PersistenceManagerInterface
     * @inject
     */
    protected $persistenceManager;

    /**
     * show form for first registration process
     */
    public function stepOneAction()
    {

    }

    /**
     * @param \MS\Patchtest\Domain\Model\User $user
     */
    public function stepOneCheckAction(\MS\Patchtest\Domain\Model\User $user)
    {
        // get user by username and password
        $presentUser = $this->userRepository->findByUsernameAndZip($user->getUsername(), $user->getZip());

        // user available
        if ($presentUser) {
            $this->redirect('stepTwo', null, null, array('user' => $presentUser));
        } else {
            // user not present
            $this->addFlashMessage('user not present', '', AbstractMessage::ERROR);
            $this->redirect('stepOne');
        }
    }

    public function initializeStepTwoAction()
    {
        $this->setHiddenUserConfiguration();
    }

    /**
     * show form to change user settings
     *
     * @param \MS\Patchtest\Domain\Model\User $user
     */
    public function stepTwoAction(\MS\Patchtest\Domain\Model\User $user)
    {
        $this->view->assign('user', $user);
    }

    /**
     *
     */
    public function initializeChangeAction()
    {
        $this->setHiddenUserConfiguration();
    }

    /**
     * @param \MS\Patchtest\Domain\Model\User $user
     */
    public function changeAction(\MS\Patchtest\Domain\Model\User $user)
    {
        // validate some stuff

        // update user
        $user->setDisable(false);

        $this->userRepository->update($user);
        $this->persistenceManager->persistAll();

        // user not present
        $this->addFlashMessage('you are active now', '', AbstractMessage::OK);
        $this->redirect('stepOne');
    }

    /**
     * overload QuerySettings to get hidden user
     */
    protected function setHiddenUserConfiguration()
    {
        $userConfiguration = $this->arguments->getArgument('user')->getPropertyMappingConfiguration();
        $userConfiguration->allowAllProperties();
        $userConfiguration->setTypeConverterOptions(
            'TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter',
            array(
                \TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter::CONFIGURATION_MODIFICATION_ALLOWED => true,
                \TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter::IGNORE_ENABLE_FIELDS => true,
                \TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter::RESPECT_STORAGE_PAGE => false,
                \TYPO3\CMS\Extbase\Property\TypeConverter\PersistentObjectConverter::RESPECT_SYS_LANGUAGE => false,
            )
        );
    }
}
